@@ -8,6 +8,7 @@
 #define ABSTRACTRUNNER_P_H
 
 #include <QReadWriteLock>
+#include <QRegularExpression>
 
 #include <KPluginMetaData>
 
@@ -28,12 +29,14 @@ class AbstractRunnerPrivate
 public:
     AbstractRunnerPrivate(AbstractRunner *r);
     ~AbstractRunnerPrivate();
+    void init();
     void init(const KPluginMetaData &pluginMetaData);
 #if KRUNNER_BUILD_DEPRECATED_SINCE(5, 72) && KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
     void init(const KService::Ptr service);
 #endif
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 77)
     void init(const QString &path);
-
+#endif
     AbstractRunner::Priority priority;
     AbstractRunner::Speed speed;
     RunnerContext::Types blackListed;
@@ -46,6 +49,9 @@ public:
     RunnerSyntax *defaultSyntax;
     bool hasRunOptions : 1;
     bool suspendMatching : 1;
+    int minLetterCount = 0;
+    QRegularExpression matchRegex;
+    bool hasMatchRegex = false;
 };
 
 } // namespace Plasma
