@@ -159,8 +159,7 @@ public:
             clearSingleRunner();
         }
 
-        AbstractRunner *loadedRunner = q->runner(singleModeRunnerId);
-        if (loadedRunner) {
+        if (AbstractRunner *loadedRunner = q->runner(singleModeRunnerId)) {
             singleRunnerWasLoaded = false;
             currentSingleRunner = loadedRunner;
             return;
@@ -342,13 +341,14 @@ QT_WARNING_POP
             KPluginLoader pluginLoader(pluginMetaData.fileName());
             const quint64 pluginVersion = pluginLoader.pluginVersion();
             if (Plasma::isPluginVersionCompatible(pluginVersion)) {
-                KPluginFactory *factory = pluginLoader.factory();
-                if (factory) {
+                if (KPluginFactory *factory = pluginLoader.factory()) {
                     const QVariantList args {
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 77)
 #if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
                         pluginMetaData.metaDataFileName(),
 #endif
                         QVariant::fromValue(pluginMetaData),
+#endif
                     };
                     runner = factory->create<AbstractRunner>(q, args);
                 } else {
@@ -455,9 +455,7 @@ QT_WARNING_POP
             return;
         }
 
-        AbstractRunner *runner = qobject_cast<AbstractRunner *>(q->sender());
-
-        if (runner) {
+        if (auto *runner = qobject_cast<AbstractRunner *>(q->sender())) {
             startJob(runner);
         }
     }
@@ -610,13 +608,13 @@ void RunnerManager::loadRunner(const KPluginMetaData &pluginMetaData)
 {
     const QString runnerName = pluginMetaData.pluginId();
     if (!runnerName.isEmpty() && !d->runners.contains(runnerName)) {
-        AbstractRunner *runner = d->loadInstalledRunner(pluginMetaData);
-        if (runner) {
+        if (AbstractRunner *runner = d->loadInstalledRunner(pluginMetaData)) {
             d->runners.insert(runnerName, runner);
         }
     }
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 77)
 void RunnerManager::loadRunner(const QString &path)
 {
     if (!d->runners.contains(path)) {
@@ -625,6 +623,7 @@ void RunnerManager::loadRunner(const QString &path)
         d->runners.insert(path, runner);
     }
 }
+#endif
 
 AbstractRunner* RunnerManager::runner(const QString &name) const
 {
@@ -739,8 +738,7 @@ void RunnerManager::run(const QueryMatch &match)
 
 QList<QAction*> RunnerManager::actionsForMatch(const QueryMatch &match)
 {
-    AbstractRunner *runner = match.runner();
-    if (runner) {
+    if (AbstractRunner *runner = match.runner()) {
         return runner->actionsForMatch(match);
     }
 
@@ -755,12 +753,7 @@ QMimeData * RunnerManager::mimeDataForMatch(const QString &id) const
 
 QMimeData * RunnerManager::mimeDataForMatch(const QueryMatch &match) const
 {
-    AbstractRunner *runner = match.runner();
-    if (runner) {
-        return runner->mimeDataForMatch(match);
-    }
-
-    return nullptr;
+    return match.isValid() ? match.runner()->mimeDataForMatch(match) : nullptr;
 }
 
 QVector<KPluginMetaData> RunnerManager::runnerMetaDataList(const QString &parentApp)
